==> sale-3.2.0.jar: revenue/sqls/outStock/farawayprice.sql <==
select * from (
select
    f_orgname,
    f_userinfo_code,
    f_user_name,
    f_userinfo_id,
    t.f_meter_classify,
    f_meter_brand,
    case when t.usestairprice_id is null then t.value else stair.value end  oldvalue,
    t.value  newvalue,
    f_table_state,
    f_filialeid,
    f_orgid,
    f_user_type,
    f_hand_date,
    f_input_date,
    f_gasproperties,
    f_depname,
    f_meternumber,
    f_price_type,
    case when t.usestairprice_id is null or t.usestairprice_id=t.f_stairprice_id then
             0 else 1 end istrue
from (
         select
             tuf.f_orgname,
             tui.f_userinfo_code,
             tui.f_user_name,
             tuf.f_userinfo_id,
             tuf.f_meter_classify,
             tg.f_meter_brand,
             stair.value,
             tuf.f_table_state,
             th.f_meter_classify  f_meter_classify1,
             tuf.f_filialeid,
             tuf.f_orgid,
             tuf.f_user_type,
             tuf.f_gasproperties,
             th.id,
             th.f_hand_date,
             th.f_input_date,
             tuf.f_depname,
             tuf.f_meternumber,
             sp.f_price_type,
             th.f_stairprice_id,
             (select top 1 f_newprice_id from t_pricechange tpc where th.f_input_date>= tpc.f_perform_date
                                                                  and f_userinfo_id = th.f_userinfo_id order by id desc ) usestairprice_id --获取抄表应该使用气价信息
         from t_handplan th
                  left join t_userfiles tuf on th.f_userfiles_id = th.f_userfiles_id
                  left join t_gasbrand tg on tg.id = tuf.f_gasbrand_id
                  left join t_userinfo tui on tuf.f_userinfo_id = tui.f_userinfo_id
                  left join (select id,f_price_type,f_price_id,f_orgid,f_state from t_stairprice ) sp
                            on sp.id = th.f_stairprice_id and tuf.f_orgid = sp.f_orgid  ---获取结算时所用气价
                  left join (
             select s.id,
                    s.f_price_type + cast((select ' ' + d.f_price_name + '阶:' + '单价' + cast(f_price as varchar) + ',上限' + cast(f_gas as varchar)
                                           from t_detailprice d where d.f_stairprice_id=s.id for xml path('')) as varchar(200)) value
             from t_stairprice s
             group by s.id,s.f_price_type
         ) stair on stair.id=sp.id  --获取结算时所用气价信息
              -- 获取抄表应该使用气价(t_pricechange)
         where  tui.f_user_state='正常'
           and th.f_meter_state = '已抄表' and th.f_hand_state = '有效'
     ) t
         left join (
    select s.id,
           s.f_price_type + cast((select ' ' + d.f_price_name + '阶:' + '单价' + cast(f_price as varchar) + ',上限' + cast(f_gas as varchar)
                                  from t_detailprice d where d.f_stairprice_id=s.id for xml path('')) as varchar(200)) value
    from t_stairprice s
    group by s.id,s.f_price_type
) stair on stair.id=t.usestairprice_id  --获取抄表应该使用气价信息
) t
where {condition}
order by f_userinfo_id desc

==> sale-3.5.1.jar: revenue/sqls/outStock/farawayprice.sql <==
select * from (
select
    f_orgname,
    f_userinfo_code,
    f_user_name,
    f_userinfo_id,
    t.f_meter_classify,
    f_meter_brand,
    case when t.usestairprice_id is null then t.value else stair.value end  oldvalue,
    t.value  newvalue,
    f_table_state,
    f_filialeid,
    f_orgid,
    f_user_type,
    f_hand_date,
    f_input_date,
    f_gasproperties,
    f_depname,
    f_meternumber,
    f_price_type,
    case when t.usestairprice_id is null or t.usestairprice_id=t.f_stairprice_id then
             0 else 1 end istrue
from (
         select
             tuf.f_orgname,
             tui.f_userinfo_code,
             tui.f_user_name,
             tuf.f_userinfo_id,
             tuf.f_meter_classify,
             tg.f_meter_brand,
             stair.value,
             tuf.f_table_state,
             th.f_meter_classify  f_meter_classify1,
             tuf.f_filialeid,
             tuf.f_orgid,
             tuf.f_user_type,
             tuf.f_gasproperties,
             th.id,
             th.f_hand_date,
             th.f_input_date,
             tuf.f_depname,
             tuf.f_meternumber,
             sp.f_price_type,
             th.f_stairprice_id,
             (select top 1 f_newprice_id from t_pricechange tpc where th.f_input_date>= tpc.f_perform_date
                                                                  and f_userinfo_id = th.f_userinfo_id order by id desc ) usestairprice_id --获取抄表应该使用气价信息
         from t_handplan th
                  left join t_userfiles tuf on tuf.f_userfiles_id = th.f_userfiles_id
                  left join t_gasbrand tg on tg.id = tuf.f_gasbrand_id
                  left join t_userinfo tui on tuf.f_userinfo_id = tui.f_userinfo_id
                  left join (select id,f_price_type,f_price_id,f_orgid,f_state from t_stairprice ) sp
                            on sp.id = th.f_stairprice_id and tuf.f_orgid = sp.f_orgid  ---获取结算时所用气价
                  left join (
             select s.id,
                    s.f_price_type + cast((select ' ' + d.f_price_name + '阶:' + '单价' + cast(f_price as varchar) + ',上限' + cast(f_gas as varchar)
                                           from t_detailprice d where d.f_stairprice_id=s.id for xml path('')) as varchar(200)) value
             from t_stairprice s
             group by s.id,s.f_price_type
         ) stair on stair.id=sp.id  --获取结算时所用气价信息
              -- 获取抄表应该使用气价(t_pricechange)
         where  tui.f_user_state='正常'
           and th.f_meter_state = '已抄表' and th.f_hand_state = '有效'
     ) t
         left join (
    select s.id,
           s.f_price_type + cast((select ' ' + d.f_price_name + '阶:' + '单价' + cast(f_price as varchar) + ',上限' + cast(f_gas as varchar)
                                  from t_detailprice d where d.f_stairprice_id=s.id for xml path('')) as varchar(200)) value
    from t_stairprice s
    group by s.id,s.f_price_type
) stair on stair.id=t.usestairprice_id  --获取抄表应该使用气价信息
) t
where {condition}
order by f_userinfo_id desc
